@@ -23,7 +23,7 @@ from __future__ import annotations
 
 from collections.abc import Sequence
 from datetime import datetime
-from typing import TYPE_CHECKING, cast, override
+from typing import TYPE_CHECKING, Any, cast, override
 
 from rsb.adapters.adapter import Adapter
 
@@ -53,6 +53,7 @@ from agentle.generations.tools.tool import Tool
 from agentle.generations.tracing.contracts.stateful_observability_client import (
     StatefulObservabilityClient,
 )
+from agentle.generations.tracing.tracing_manager import TracingManager
 
 if TYPE_CHECKING:
     from google.auth.credentials import Credentials
@@ -89,6 +90,7 @@ class GoogleGenerationProvider(GenerationProvider, PriceRetrievable):
         http_options: HTTP options for the Google AI client.
         message_adapter: Adapter to convert Agentle messages to Google Content format.
         function_calling_config: Configuration for function calling behavior.
+        tracing_manager: Manager for tracing generation activities.
     """
 
     use_vertex_ai: bool
@@ -100,6 +102,7 @@ class GoogleGenerationProvider(GenerationProvider, PriceRetrievable):
     http_options: HttpOptions | None
     message_adapter: Adapter[AssistantMessage | UserMessage | DeveloperMessage, Content]
     function_calling_config: FunctionCallingConfig
+    tracing_manager: TracingManager
 
     def __init__(
         self,
@@ -143,6 +146,9 @@ class GoogleGenerationProvider(GenerationProvider, PriceRetrievable):
         self.http_options = http_options
         self.message_adapter = message_adapter or MessageToGoogleContentAdapter()
         self.function_calling_config = function_calling_config or {}
+        self.tracing_manager = TracingManager(
+            tracing_client=tracing_client, provider_name=self.organization
+        )
 
     @property
     @override
@@ -196,13 +202,11 @@ class GoogleGenerationProvider(GenerationProvider, PriceRetrievable):
 
         start = datetime.now()
         used_model = model or self.default_model
-
-        # Get trace params if available
         _generation_config = generation_config or GenerationConfig()
-        trace_params = _generation_config.trace_params
+        is_final_generation = response_schema is not None
 
         # Prepare input data for tracing
-        input_data: dict[str, object] = {
+        input_data: dict[str, Any] = {
             "messages": [
                 {
                     "role": msg.role,
@@ -216,10 +220,22 @@ class GoogleGenerationProvider(GenerationProvider, PriceRetrievable):
             "top_k": _generation_config.top_k,
             "max_output_tokens": _generation_config.max_output_tokens,
             "tools_count": len(tools) if tools else 0,
+            "message_count": len(messages),
+            "has_tools": tools is not None and len(tools) > 0,
+            "has_schema": response_schema is not None,
         }
 
+        # Set up tracing using the tracing manager
+        trace_client, generation_client = await self.tracing_manager.setup_trace(
+            generation_config=_generation_config,
+            model=used_model,
+            input_data=input_data,
+            is_final_generation=is_final_generation,
+        )
+
         # Extract trace metadata if available
-        trace_metadata: dict[str, object] = {}
+        trace_metadata: dict[str, Any] = {}
+        trace_params = _generation_config.trace_params
         if "metadata" in trace_params:
             metadata_val = trace_params["metadata"]
             if isinstance(metadata_val, dict):
@@ -228,26 +244,6 @@ class GoogleGenerationProvider(GenerationProvider, PriceRetrievable):
                     if isinstance(k, str):
                         trace_metadata[k] = v
 
-        # Set up tracing with user-customized trace parameters
-        generation_tracing = self.tracing_client.map(
-            lambda client: client.model_generation(
-                provider=self.organization,
-                model=used_model,
-                input_data=input_data,
-                metadata={
-                    "config": {
-                        k: v
-                        for k, v in _generation_config.__dict__.items()
-                        if not k.startswith("_") and not callable(v)
-                    },
-                    **trace_metadata,
-                },
-                name=trace_params.get(
-                    "name", f"{self.organization}_{used_model}_generation"
-                ),
-            )
-        )
-
         try:
             _http_options = self.http_options or types.HttpOptions()
             # change so if the timeout is provided in the constructor and the user doesnt inform the timeout in the generation config, the timeout in the constructor is used
@@ -330,7 +326,7 @@ class GoogleGenerationProvider(GenerationProvider, PriceRetrievable):
             ).adapt(generate_content_response)
 
             # Prepare output data for tracing
-            output_data: dict[str, object] = {
+            output_data: dict[str, Any] = {
                 "completion": response.text,
                 "usage": {
                     "input_tokens": response.usage.prompt_tokens
@@ -354,31 +350,41 @@ class GoogleGenerationProvider(GenerationProvider, PriceRetrievable):
                 else:
                     output_data["user_defined_output"] = custom_output
 
-            # End the generation with success
-            generation_tracing.map(
-                lambda client: client.complete_with_success(
-                    output=output_data,
-                    start_time=start,
-                    metadata=trace_metadata,
-                )
+            # Complete the generation and trace if needed
+            await self.tracing_manager.complete_generation(
+                generation_client=generation_client,
+                start_time=start,
+                output_data=output_data,
+                trace_metadata=trace_metadata,
             )
 
+            # If this is the final generation, complete the trace
+            if is_final_generation:
+                final_output = {
+                    "final_response": response.text,
+                    "structured_output": response.parsed
+                    if hasattr(response, "parsed")
+                    else None,
+                    "usage": output_data["usage"],
+                }
+                await self.tracing_manager.complete_trace(
+                    trace_client=trace_client,
+                    generation_config=_generation_config,
+                    output_data=final_output,
+                    success=True,
+                )
+
             return response
 
-        except Exception:
-            # Capture the exception details
-            import sys
-
-            _, exc_value, _ = sys.exc_info()
-
-            # Record error using the new helper method
-            generation_tracing.map(
-                lambda client: client.complete_with_error(
-                    error=str(exc_value) if exc_value else "Unknown error",
-                    start_time=start,
-                    error_type="Exception",
-                    metadata=trace_metadata,
-                )
+        except Exception as e:
+            # Handle errors using the tracing manager
+            await self.tracing_manager.handle_error(
+                generation_client=generation_client,
+                trace_client=trace_client,
+                generation_config=_generation_config,
+                start_time=start,
+                error=e,
+                trace_metadata=trace_metadata,
             )
             # Re-raise the exception
             raise
